using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Reflection;
using FieldSoftware;
using FieldSoftware.PrinterCE_NetCF;
using System.IO;

namespace PrCEDemo_NetCF
{
	public class Demos
	{
		public Demos()
		{
		}
		public static string Version
		{
			get
			{
				string retstr=string.Format("PrinterCE.NetCF v{0:0}.{1:0}.{2:0}.{3:0}",PrinterCE.PRINTERCE_NETCF_MAJOR,PrinterCE.PRINTERCE_NETCF_MINOR,PrinterCE.PRINTERCE_NETCF_BUILD,PrinterCE.PRINTERCE_NETCF_REVISION);
				return retstr;
			}
		}
        const string LICENSE_KEY = "YOURLICENSEKEY";

        public static void HelloWorld()
		{
			PrinterCE prce = null;
			try 
			{
				prce = new PrinterCE(LICENSE_KEY); //Create instance of PrinterCE class
                prce.ScaleMode = PrinterCE.MEASUREMENT_UNITS.INCHES; //Everything in inches
                prce.SelectPrinter(true);

                double pgwd = prce.PrPgWidth;
                double pght = prce.PrPgHeight;
                prce.DrawWidth = 0.03;
                prce.ForeColor = Color.DarkGreen;

                double x1, y1, x2, y2;
                x1 = 0.05;
                y1 = 0.03;
                x2 = pgwd - 0.03;
                y2 = pght - 0.03;

                prce.DrawRect(x1, y1, x2, y2);
                prce.JustifyHoriz = PrinterCE.JUSTIFY_HORIZ.CENTER;
                prce.JustifyVert = PrinterCE.JUSTIFY_VERT.CENTER;
                prce.ForeColor = Color.DarkBlue;
                string mystr = "Hello World";
                double cx,cy;
                cx=pgwd/2;
                cy=pght/2;
                prce.DrawText(mystr, cx,cy);
                double stwd, stht;
                stwd = prce.GetStringWidth(mystr)+0.2;
                stht = prce.GetStringHeight+0.1;
                prce.ForeColor = Color.DarkRed;
                prce.DrawWidth = 0.03;
                prce.DrawRect(cx - stwd / 2, cy - stht / 2, cx + stwd / 2, cy + stht / 2);
                prce.ForeColor = Color.DarkTurquoise;
                prce.DrawWidth = 0.015;
                prce.DrawLine(x1, y1, cx - stwd / 2, cy - stht / 2);
                prce.DrawLine(x1, y2, cx - stwd / 2, cy + stht / 2);
                prce.DrawLine(x2, y1, cx + stwd / 2, cy - stht / 2);
                prce.DrawLine(x2, y2, cx + stwd / 2, cy + stht / 2);
				prce.EndDoc(); //Done with this page - print it
			}
			catch (PrinterCEException exc) 
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
				MessageBox.Show("PrinterCE Exception","Exception");
			}
			finally
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
			}
		}

		public static void BarcodeCETest() 
		{
			BarcodeCE bcode = null;
			try
			{
                bcode = new BarcodeCE(LICENSE_KEY); //Create instance of BarcodeCE class
                bcode.SelectPrinter(true);
				bcode.ScaleMode = BarcodeCE.MEASUREMENT_UNITS.INCHES;
				double x, y, wid;
				y = 0;
                double pgwd = bcode.PrPgWidth;
                double pght = bcode.PrPgHeight;
                double fht = bcode.GetStringHeight;
                if (pgwd >= 6.95 && pght >= 7.5)
                {
                    bcode.DrawText("---- UPC EAN13, EAN8 ----", 0, y);
                    y += fht;
                    wid = bcode.DrawUPC("781572", "31856", "90000", 0, y, true, BarcodeCE.TYPE_UPC.UPC_EAN13, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    wid = bcode.DrawUPC("0123456", "", "", wid + 0.25, y, true, BarcodeCE.TYPE_UPC.UPC_EAN8, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.75;
                    bcode.DrawText("---- UPC : A+2, A, E+2, E ----", 0, y);
                    y += fht;
                    wid = bcode.DrawUPC("25274", "79382", "02", 0, y, true, BarcodeCE.TYPE_UPC.UPC_A, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    x = wid + 0.25;
                    wid = bcode.DrawUPC("24100", "16149", "", x, y, true, BarcodeCE.TYPE_UPC.UPC_A, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    x = x + wid + 0.25;
                    wid = bcode.DrawUPC("123643", "", "02", x, y, true, BarcodeCE.TYPE_UPC.UPC_E, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    x = x + wid + 0.25;
                    wid = bcode.DrawUPC("522361", "", "", x, y, true, BarcodeCE.TYPE_UPC.UPC_E, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.75;
                    bcode.DrawText("---- Code MSI Plessey: Mod1010, Mod1110, Mod10----", 0, y);
                    y += fht;
                    wid = bcode.DrawMSI("987654", 0, y, true, BarcodeCE.TYPE_MSI.MOD1010, BarcodeCE.BARCODE_FIT.TIGHT);
                    x = wid + 0.25;
                    wid = bcode.DrawMSI("987654", x, y, true, BarcodeCE.TYPE_MSI.MOD1110, BarcodeCE.BARCODE_FIT.TIGHT);
                    wid = bcode.DrawMSI("987654", x + wid + 0.25, y, true, BarcodeCE.TYPE_MSI.MOD10, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.6;
                    bcode.DrawText("---- Code 93 : Base, Extend ----", 0, y);
                    y += fht;
                    wid = bcode.DrawCode93("CODE 93", 0, y, true, BarcodeCE.BARCODE_FIT.TIGHT, true);
                    wid = bcode.DrawCode93("Extend 93", wid + 0.25, y, true, BarcodeCE.BARCODE_FIT.TIGHT, true);
                    y += 0.6;
                    bcode.DrawText("---- Code 128 : Auto, Auto, UCC128 ----", 0, y);
                    y += fht;
                    wid = bcode.DrawCode128("CODE 128", 0, y, true, BarcodeCE.TYPE_128.AUTO, BarcodeCE.BARCODE_FIT.TIGHT);
                    x = wid + 0.2;
                    wid = bcode.DrawCode128("1234 abc", x, y, true, BarcodeCE.TYPE_128.AUTO, BarcodeCE.BARCODE_FIT.TIGHT);
                    wid = bcode.DrawCode128("0123456789012345678", x + wid + 0.2, y, true, BarcodeCE.TYPE_128.UCC128, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.75;
                    bcode.DrawText("---- Codabar : Base & Checksum16 ----", 0, y);
                    y += fht;
                    wid = bcode.DrawCodabar("a$123b", 0, y, true, BarcodeCE.TYPE_CODABAR.BASE, BarcodeCE.BARCODE_FIT.TIGHT);
                    x = wid + 0.25;
                    wid = bcode.DrawCodabar("A123456B", wid + 0.25, y, true, BarcodeCE.TYPE_CODABAR.CHECKSUM16, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.6;
                    bcode.DrawText("---- CODE 3 of 9 : Normal, Checksum, HIBC, Normal ----", 0, y);
                    y += fht;
                    wid = bcode.DrawCode39("Extend39", 0, y, true, BarcodeCE.TYPE_39.NORMAL, BarcodeCE.BARCODE_FIT.TIGHT, true);
                    wid = bcode.DrawCode39("MOD43", wid + 0.25, y, true, BarcodeCE.TYPE_39.CHECKSUM, BarcodeCE.BARCODE_FIT.TIGHT, false);
                    y += 0.5;
                    wid = bcode.DrawCode39("HIBC CODE", 0, y, true, BarcodeCE.TYPE_39.HIBC, BarcodeCE.BARCODE_FIT.TIGHT, false);
                    wid = bcode.DrawCode39("LIBRARY", wid + 0.25, y, true, BarcodeCE.TYPE_39.NORMAL, BarcodeCE.BARCODE_FIT.TIGHT, false);
                    y += 0.6;
                    bcode.DrawText("---- CODE 2 of 5 : Base, Checksum ----", 0, y);
                    y += fht;
                    wid = bcode.Draw2of5("1991", 0, y, true, BarcodeCE.TYPE_2of5.BASE, BarcodeCE.BARCODE_FIT.TIGHT);
                    wid = bcode.Draw2of5("12345678", wid + 0.25, y, true, BarcodeCE.TYPE_2of5.CHECKSUM, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.6;
                    bcode.DrawText("---- PostNet ----", 0, y);
                    y += fht;
                    wid = bcode.DrawPostnet("95709-9694", 0, y, true);
                    wid = bcode.DrawPostnet("94294-0894", wid + 0.25, y, true);
                }
                else
                {
                    x = pgwd / 2;
                    bcode.JustifyHoriz = PrinterCE.JUSTIFY_HORIZ.CENTER;
                    bcode.DrawText("---- UPC A ----", x, y);
                    y += fht;
                    wid = bcode.DrawUPC("24100", "16149", "", x, y, true, BarcodeCE.TYPE_UPC.UPC_A, 0, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.75;
                    if (y+0.8 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    bcode.DrawText("---- Code MSI Plessey ----", x, y);
                    y += fht;
                    wid = bcode.DrawMSI("987654", x, y, true, BarcodeCE.TYPE_MSI.MOD1010, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.6;
                    if (y+0.8 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    bcode.DrawText("---- Code 93 ----", x, y);
                    y += fht;
                    wid = bcode.DrawCode93("CODE 93", x, y, true, BarcodeCE.BARCODE_FIT.TIGHT, true);
                    y += 0.6;
                    if (y + 0.95 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    bcode.DrawText("---- Code 128 ----", x, y);
                    y += fht;
                    wid = bcode.DrawCode128("1234 abc", x, y, true, BarcodeCE.TYPE_128.AUTO, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.75;
                    if (y + 0.8 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    bcode.DrawText("---- Codabar ----", x, y);
                    y += fht;
                    wid = bcode.DrawCodabar("A123456B", x, y, true, BarcodeCE.TYPE_CODABAR.CHECKSUM16, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.6;
                    if (y + 0.8 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    bcode.DrawText("---- CODE 3 of 9 ----", x, y);
                    y += fht;
                    wid = bcode.DrawCode39("LIBRARY", x, y, true, BarcodeCE.TYPE_39.NORMAL, BarcodeCE.BARCODE_FIT.TIGHT, false);
                    y += 0.6;
                    if (y + 0.8 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    bcode.DrawText("---- CODE 2 of 5 ----", x, y);
                    y += fht;
                    wid = bcode.Draw2of5("12345678", x, y, true, BarcodeCE.TYPE_2of5.CHECKSUM, BarcodeCE.BARCODE_FIT.TIGHT);
                    y += 0.6;
                    if (y + 0.8 >= pght)
                    {
                        bcode.NewPage();
                        y = 0;
                    }
                    if (pgwd >= 3)
                    {
                        bcode.DrawText("---- PostNet ----", x, y);
                        y += fht;
                        wid = bcode.DrawPostnet("94294-0894", x, y, true);
                    }
                }
				bcode.EndDoc(); //Done with this page - print it
			}
			catch (PrinterCEException exc) 
			{
				if (bcode!=null) 
				{
					bcode.ShutDown(); //Done - free PrinterCE resources 
				}
				bcode=null;
				MessageBox.Show("BarcodeCE Exception","Exception");
			}
			finally
			{
				if (bcode!=null) 
				{
  					bcode.ShutDown(); //Done - free PrinterCE resources 
				}
				bcode=null;
			}
		}

		public static void TextWheel()
		{
			PrinterCE prce = null;
			try //Use 
			{
				prce = new PrinterCE(LICENSE_KEY); //Create instance of PrinterCE class
				prce.ScaleMode = PrinterCE.MEASUREMENT_UNITS.INCHES; //Everything in inches
				prce.SelectPrinter(true);
				string str, orientstr;
                int font1, font2, font3;
                if (prce.PrPgWidth > 4)
                {
                    font1=14;
                    font2=18;
                    font3 = 26;
                }
                else if (prce.PrPgWidth<=2) {
                    font1=9;
                    font2=12;
                    font3 = 18;
                }
                else
                {
                    font1=12;
                    font2=16;
                    font3 = 22;
                }
				for (int lp=0; lp<4; lp++) 
				{
					prce.TextX = prce.PrPgWidth / 2;
					prce.TextY = prce.PrPgHeight / 2;
					prce.FontBold = false;
					prce.FontItalic = false;
                    prce.FontSize = font1;
					switch (lp) 
					{
						case 1:
							prce.Rotation = PrinterCE.ROTATION_TYPE.EAST;
							str="East";
							break;
						case 2:
							prce.Rotation = PrinterCE.ROTATION_TYPE.SOUTH;
							str="South";
							break;
						case 3:
							prce.Rotation = PrinterCE.ROTATION_TYPE.WEST;
							str="West";
							break;
						default:
						case 0:
							prce.Rotation = PrinterCE.ROTATION_TYPE.NORTH;
							str="North";
							break;
					}
                    prce.ForeColor = Color.Black; //Set color to black
                    orientstr = (prce.PrOrientation == PrinterCE.ORIENTATION.PORTRAIT) ? "Portrait" : "Landscape";
                    prce.DrawText(orientstr + " Orientation"); 
                    prce.FontSize = font2;
					prce.FontBold = true;
					prce.FontItalic = true;
					prce.ForeColor = Color.Magenta; //Set color
					prce.DrawText("Bold & italics");
                    prce.FontSize = font3;
					prce.ForeColor = Color.Cyan; //Set color
                    prce.DrawText(str); //position first line
                }
				prce.EndDoc(); //Done with this page - print it
			}
			catch (PrinterCEException exc) 
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
				MessageBox.Show("PrinterCE Exception","Exception");
			}
			finally
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
			}
		}

		public static void LineFun() 
		{
			PrinterCE prce = null;
			try 
			{
				prce = new PrinterCE(LICENSE_KEY); //Create instance of PrinterCE class
				prce.SelectPrinter(true);
				double wd,ht,x1,y1,x2,y2;
				wd = prce.PrPgWidth;
                ht = prce.PrPgHeight;
                //Center vertically & horizontally
				prce.JustifyHoriz = PrinterCE.JUSTIFY_HORIZ.CENTER;
				prce.JustifyVert = PrinterCE.JUSTIFY_VERT.CENTER; 
				//Set font stuff
                int fs1, fs2;
                if (wd > 4.5*1440 && ht>3*1440)
                {
                    fs1 = 36;
                    fs2 = 32;
                }
                else if (wd <= 3*1440 || ht<(1.5*1440))
                {
                    fs1 = 15;
                    fs2 = 10;
                }
                else
                {
                    fs1 = 22;
                    fs2 = 16;
                }
				prce.FontName = "Courier New";
				prce.FontSize = fs1;
				prce.FontItalic = false;
				prce.ForeColor = Color.DarkMagenta;
				//ScaleMode defaults to TWIPS - (1440 twips per inch)
                x1 = wd / 2;
                double stht = prce.GetStringHeight;
                if (ht < 3 * 1440)
                {
                    ht -= stht;
                    y1 = stht / 2;
                }
                else
                {
                    ht = 2 * 1440;
                    y1 = 720;
                }
				prce.DrawText("Line Fun Demo", x1, y1);
				//Rectangle area - width of page by 2 inches 
				x1 = 0;
				x2 = wd;
				y1 += stht/2;  
                if (ht > 2 * 1440) ht = 2 * 1440;
                //if (ht > wd) ht = wd;
				y2 = y1 + ht;
				prce.ForeColor = Color.Black;
                int dwid = 72;
                x1 += dwid;
                x2 -= dwid;
                y1 += dwid;
                y2 -= dwid;
                wd = x2 - x1;
                ht = y2 - y1;
                prce.DrawWidth = dwid; 
                prce.DrawRect(x1, y1, x2, y2);


				prce.DrawWidth = 10;
				double deltax,deltay, offsetx, offsety;
				deltax = wd / 25;
				deltay = ht / 25;
				offsetx = x1;
				offsety = y2-deltay;
				for (int lp=0;lp<24;lp++) 
				{
					offsetx = offsetx + deltax;
					prce.DrawLine(x1 + offsetx, y1, x1, offsety);
					prce.DrawLine(x2 - offsetx, y1, x2, offsety);
					offsety = offsety - deltay;
				}
				//Put an ellipse filled with a color inside our rectangle
				prce.DrawWidth = 20;
				prce.FillStyle = 0; 
				prce.FillColor = Color.Pink;
				//calc new y1 & y2
				y1 = y1 + 720;
				y2 = y2 - 120;
				x1 = wd / 2;
				prce.DrawEllipse(x1 - wd / 3, y1, x1 + wd / 3, y2);
				//Put some text in the middle
				prce.ForeColor = Color.DarkBlue;
				prce.FontSize = fs2;
				prce.FontName = "Arial";
                prce.FontItalic = true;
                prce.DrawText("PrinterCE.NetCF", x1, y1 + (y2 - y1) / 2);
				prce.EndDoc(); //Done with this page - print it
			}
			catch (PrinterCEException exc) 
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
				MessageBox.Show("PrinterCE Exception","Exception");
			}
			finally
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
			}
		}

		public static void Thumbnails() 
		{
			PrinterCE prce = null;
			try 
			{
				prce = new PrinterCE(LICENSE_KEY); //Create instance of PrinterCE class
				prce.SelectPrinter(true);
				//Set up for number of images to print across and down each page
				prce.ScaleMode = PrinterCE.MEASUREMENT_UNITS.INCHES; //Everything in inches
				double pgwd,pght,deltax,deltay,nextx,nexty,startx,starty,usewd,useht;
				pgwd=prce.PrPgWidth;
				pght=prce.PrPgHeight;

				//Our goal is to make each image approx 1 x 1 inches - calculate how many we can fit across and down page
				int cntacross,cntdown;
				cntacross=(int) pgwd;
                if (cntacross <= 1) cntacross=2;    //new
				cntdown=(int) pght;
                if (cntdown < 1) cntdown = 1;    //new
                deltax = pgwd / cntacross;
				deltay=pght/cntdown;
                //new - if one direction is much smaller than other, see if need refit
                if (deltax < deltay)
                {
                    cntdown = (int) (pght / deltax);
                    if (cntdown < 1) cntdown = 1;    //new
                    deltay = pght / cntdown;
                }
                else
                {
                    cntacross = (int) (pgwd / deltay);
                    if (cntacross <= 1) cntacross = 2;    //new
                    deltax = pgwd / cntacross;
                }
				//For actual image bounding size, use deltax,deltay with a bit of space between each image
				usewd=deltax-0.1;
				useht=deltay-0.25;	//Leave space for filename text

				prce.JustifyHoriz=PrinterCE.JUSTIFY_HORIZ.CENTER;	//Center each image
				startx=nextx=deltax/2;
				starty=nexty=deltay/2;
				prce.FontSize=9;	//Set point size for printing image file name

				string pathname=@"\Images";
				int pathlen=pathname.Length;
				if (Directory.Exists(pathname))
				{
					double wid,ht;
					string[] filelist = Directory.GetFiles(pathname,"*.*");
                    Array.Sort(filelist);
					foreach (string file in filelist) 
					{
						if (prce.GetPictureDims(file,out wid,out ht)) 
						{
							prce.JustifyVert=PrinterCE.JUSTIFY_VERT.CENTER;
							prce.DrawPicture(file,nextx,nexty,usewd,useht,true);
							//Print out filename
							prce.JustifyVert=PrinterCE.JUSTIFY_VERT.BOTTOM;
							//Move past path to get just filename
							prce.DrawText(file.Substring(pathlen+1),nextx,nexty+starty+0.05);
							//Move to next image spot on page
							nextx+=deltax;
							if (nextx>pgwd) 
							{
								nextx=startx;
								nexty+=deltay;
								if (nexty>pght) 
								{
									prce.NewPage();
									nexty=starty;
								}
							}
						}
					}
				}
                prce.NewPage();
			}
			catch (PrinterCEException exc) 
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
				MessageBox.Show("PrinterCE Exception","Exception");
			}
			finally
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
			}
		}

		public static void TextColumns() 
		{
			PrinterCE prce = null;
			try 
			{
				// Let's put up a file dialog and let user select .TXT file to print
				FileDialog fdg = new OpenFileDialog();
				fdg.InitialDirectory = @"\";
				fdg.Filter = "Text files (*.txt)|*.txt";

				if (fdg.ShowDialog() == DialogResult.OK) 
				{
					string fname=fdg.FileName;
					StreamReader myText=new StreamReader(fdg.FileName);
					string text = myText.ReadToEnd();
					// We are going to loop printing columns until all text has been printed
					prce = new PrinterCE(LICENSE_KEY); //Create instance of PrinterCE class
					prce.SelectPrinter(true);
					prce.ScaleMode = PrinterCE.MEASUREMENT_UNITS.INCHES; //Everything in inches

					double pwid=prce.PrPgWidth;
					//
					// Print the contents of text box - if paper width > 4 inches, use 2 columns
					//
					// Column width for each column will be half of paper width minus center margin

                    bool TwoColumns = (pwid>4);
					double colwid, colspace;
                    if (TwoColumns)
                    {
                        colspace = (pwid > 6) ? 0.75 : 0.25;
                        colwid = (pwid - colspace) / 2;
                    }
                    else
                    {
                        colspace = 0;
                        colwid = pwid;
                    }

					double left=0;
					int rlen;
					for (;;) 
					{
						//Use DrawTextFlow with "NOFORMFEED" flow option - this will flow text into next column
						// and return number of characters printed in the column
						rlen=prce.DrawTextFlow(text,0,0,left,-1,colwid,-1,-1,PrinterCE.FLOW_OPTIONS.NOFORMFEED);
						if (rlen==0 || rlen>=text.Length) break;  //If nothing printed, we are done
						text=text.Remove(0,rlen);  //Get rid of the text printed in this column
						// If we just printed left column, move to right side of page. If printed right column
						// do NewPage and prepare to print left column on next page.
						if (TwoColumns && left==0) 
						{
                            left = colwid + colspace;
						}
						else 
						{
							left=0;
							prce.NewPage();
						}
					}
					prce.EndDoc(); //Done with this page - print it
				}
			}
			catch (PrinterCEException exc) 
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
				MessageBox.Show("PrinterCE Exception","Exception");
			}
			finally
			{
				if (prce!=null) 
				{
					prce.ShutDown(); //Done - free PrinterCE resources 
				}
				prce=null;
			}
		}

		public static void AsciiCEdemo() 
		{
			string[] AsciiBuff= {
				" ",
				" ",
				"AsciiCE Printing for .Net Compact Framework",
				"   (Included with PrinterCE.NetCF)",
				"-------------------------------------------",
				" ",
				"AsciiCE allows your application to:",
				" * Send text to ANY Ascii printer",
				" * Offers maximum printing speed",
				" * Offers maximum printer choices",
				" * Suitable for text-only printing",
				" * Print via Bluetooth, Infrared & Serial ports",
				" * Send printer control strings",
				" * Read data from Mag Card Readers",
				" ",
				"- Works with .Net Compact Framework devices",
				"  including Windows Mobile and CE.Net platforms.",
				" ",
				"- Supports C# and VB.Net for Visual Studio.Net CF",
				" ",
				"- AsciiCE is included with PrinterCE.NetCF",
				" ",
				"For more info:",
				" * http://www.fieldsoftware.com/PrinterCE_NetCF.htm",
				" * email: techsupport@fieldsoftware.com",
			};

			PortSetup port = new PortSetup();
			port.PortSelect.SelectedIndex=0;
			port.BaudRate.SelectedIndex=0;
			port.Handshake.SelectedIndex=0;
			if (port.ShowDialog() != DialogResult.OK) return;
		
			AsciiCE.ASCIIPORT[] portlookup = 
			{
				AsciiCE.ASCIIPORT.INFRARED,
				AsciiCE.ASCIIPORT.COM1, 
				AsciiCE.ASCIIPORT.COM2, 
				AsciiCE.ASCIIPORT.COM3, 
				AsciiCE.ASCIIPORT.COM4, 
				AsciiCE.ASCIIPORT.COM5, 
				AsciiCE.ASCIIPORT.COM6, 
				AsciiCE.ASCIIPORT.COM7, 
				AsciiCE.ASCIIPORT.COM8, 
				AsciiCE.ASCIIPORT.COM9, 
				AsciiCE.ASCIIPORT.SOCKETCOM_BT,
				AsciiCE.ASCIIPORT.ANYCOM_BT,
				AsciiCE.ASCIIPORT.COMPAQ_BT,
				AsciiCE.ASCIIPORT.TOFILE,
			};
			AsciiCE.PORT_SPEED[] portspeed =
			{
				AsciiCE.PORT_SPEED.DONT_CARE,
				AsciiCE.PORT_SPEED.S_4800, 
				AsciiCE.PORT_SPEED.S_9600, 
				AsciiCE.PORT_SPEED.S_19200, 
				AsciiCE.PORT_SPEED.S_38400, 
				AsciiCE.PORT_SPEED.S_57600, 
				AsciiCE.PORT_SPEED.S_115200, 
			};
			AsciiCE.SERIAL_HANDSHAKE[] handshake =
			{
				AsciiCE.SERIAL_HANDSHAKE.DONT_CARE,
				AsciiCE.SERIAL_HANDSHAKE.SOFTWARE,
				AsciiCE.SERIAL_HANDSHAKE.HARDWARE,
				AsciiCE.SERIAL_HANDSHAKE.NO_HANDSHAKE,
			};
			AsciiCE.ASCIIPORT useport = portlookup[port.PortSelect.SelectedIndex];
			AsciiCE.PORT_SPEED usespeed = portspeed[port.BaudRate.SelectedIndex];
			AsciiCE.SERIAL_HANDSHAKE usehandshake = handshake[port.Handshake.SelectedIndex];
			port.Visible=false;

			AsciiCE asciice = null;
			try 
			{
				asciice = new AsciiCE(LICENSE_KEY); //Create instance of PrinterCE class
				if (asciice.SelectPort(useport,usespeed,usehandshake)) 
				{
					foreach(string nextstr in AsciiBuff)
					{
						asciice.Text(nextstr);
						asciice.CrLf();	//Move to next line
					}
					if (port.FormFeed.Checked) 
					{
						asciice.FormFeed();
					}
					else //feed paper a bit
					{
						asciice.CrLf();
						asciice.CrLf();
						asciice.CrLf();
					}
				}
			}
			catch (PrinterCEException exc) 
			{
				if (asciice!=null) 
				{
					asciice.ShutDown(); //Done - free PrinterCE resources 
				}
				asciice=null;
				MessageBox.Show("AsciiCE Exception","Exception");
			}
			finally
			{
				if (asciice!=null) 
				{
					asciice.ClosePort(); //Done - free PrinterCE resources 
				}
				asciice=null;
			}
		}
	}
}
